@@ -12,12 +12,12 @@ cleanup_regex = {
     # This matches everything except spaces, parens, colon, comma, and period
     "most_punctuations": re.compile(r"([^\.():,\s]+)$"),
     # This matches everything except a space.
-    "all_punctuations": re.compile("([^\s]+)$"),
+    "all_punctuations": re.compile(r"([^\s]+)$"),
 }
 
 
 def last_word(text, include="alphanum_underscore"):
-    """
+    R"""
     Find the last word in a sentence.
 
     >>> last_word('abc')
@@ -41,9 +41,9 @@ def last_word(text, include="alphanum_underscore"):
     >>> last_word('bac $def', include='most_punctuations')
     '$def'
     >>> last_word('bac \def', include='most_punctuations')
-    '\\\\def'
+    '\\def'
     >>> last_word('bac \def;', include='most_punctuations')
-    '\\\\def;'
+    '\\def;'
     >>> last_word('bac::def', include='most_punctuations')
     'def'
     """
