@@ -121,7 +121,7 @@ def get_editor_query(sql):
     # The reason we can't simply do .strip('\e') is that it strips characters,
     # not a substring. So it'll strip "e" in the end of the sql also!
     # Ex: "select * from style\e" -> "select * from styl".
-    pattern = re.compile("(^\\\e|\\\e$)")
+    pattern = re.compile(r"(^\\e|\\e$)")
     while pattern.search(sql):
         sql = pattern.sub("", sql)
 
@@ -245,7 +245,7 @@ def subst_favorite_query_args(query, args):
                 + query,
             ]
 
-    match = re.search("\\?|\\$\d+", query)
+    match = re.search(r"\?|\$\d+", query)
     if match:
         return [
             None,
